@@ -1,6 +1,9 @@
 #![feature(array_from_fn)]
 
 pub mod error;
+
+#[cfg(feature = "endian")]
+pub mod endian;
 #[cfg(feature = "extra")]
 pub mod extra;
 
@@ -9,7 +12,7 @@ mod primitives;
 use std::io::Write;
 
 #[cfg(feature = "derive")]
-pub use parst_derive::Parsable;
+pub use parst_derive::{Deparsable, Parsable};
 
 use crate::error::Error;
 
